class Admin::TagsController < ApplicationController
  before_action :require_admin

  def index
    @tags = Tag.includes(:images).all
    
    # Group tags by catalog
    grouped_tags = @tags.group_by(&:catalog)
    
    # Sort catalogs alphabetically, with nil catalog at the end
    sorted_catalogs = grouped_tags.keys.compact.sort
    sorted_catalogs << nil if grouped_tags.key?(nil)
    
    # Create the final grouped tags hash with sorted catalogs
    @grouped_tags = {}
    sorted_catalogs.each do |catalog|
      @grouped_tags[catalog] = grouped_tags[catalog]
    end
    
    render inertia: 'admin/tags/Index', props: {
      tags: @grouped_tags.transform_values do |tags|
        tags.map do |tag|
          tag.as_json(only: [:id, :name, :catalog], methods: [:images_count])
        end
      end
    }
  end

  def create
    @tag = Tag.new(tag_params)
    
    if @tag.save
      redirect_to admin_tags_path, notice: 'Tag was successfully created.'
    else
      # Return to index with errors
      redirect_to admin_tags_path, alert: @tag.errors.full_messages.join(', ')
    end
  end

  def update
    @tag = Tag.find(params[:id])
    
    if @tag.update(tag_params)
      redirect_to admin_tags_path, notice: 'Tag was successfully updated.'
    else
      redirect_to admin_tags_path, alert: @tag.errors.full_messages.join(', ')
    end
  end

  def destroy
    @tag = Tag.find(params[:id])
    
    if @tag.destroy
      redirect_to admin_tags_path, notice: 'Tag was successfully deleted.'
    else
      redirect_to admin_tags_path, alert: 'Unable to delete tag.'
    end
  end
  
  private
  
  def tag_params
    params.require(:tag).permit(:name, :catalog)
  end
  
  def require_admin
    unless authenticated?.user&.roles&.include?('admin')
      render inertia: 'Forbidden', props: { message: 'You do not have permission to access this page.' }, status: :forbidden
    end
  end
end
