class TagsController < ApplicationController
  # allow_unauthenticated_access only: [ :index ]

  def index
    @tags = Tag.includes(:images).all

    # Group tags by catalog
    grouped_tags = @tags.group_by(&:catalog)

    # Sort catalogs alphabetically, with nil catalog at the end
    sorted_catalogs = grouped_tags.keys.compact.sort
    sorted_catalogs << nil if grouped_tags.key?(nil)

    # Create the final grouped tags hash with sorted catalogs
    @grouped_tags = {}
    sorted_catalogs.each do |catalog|
      @grouped_tags[catalog] = grouped_tags[catalog]
    end

    data = @grouped_tags.transform_values do |tags|
      tags.map do |tag|
        tag.as_json(only: [ :id, :name, :catalog ], methods: [ :images_count ])
      end
    end

    respond_to do |format|
      format.html do
        render inertia: "tags/Index", props: {
          tags: data
        }
      end

      format.json { render json: { tags: data } }
    end
  end

  # def new
  #   render inertia: "tags/New"
  # end

  # def create
  #   @tag = Tag.new(tag_params)

  #   if @tag.save
  #     redirect_to tags_path, notice: "Tag was successfully created."
  #   else
  #     render inertia: "tags/New", props: {
  #       tag: @tag.as_json,
  #       errors: @tag.errors
  #     }, status: :unprocessable_entity
  #   end
  # end

  # def edit
  #   @tag = Tag.find(params[:id])

  #   render inertia: "tags/Edit", props: {
  #     tag: @tag.as_json(only: [ :id, :name, :catalog ])
  #   }
  # end

  # def update
  #   @tag = Tag.find(params[:id])

  #   if @tag.update(tag_params)
  #     redirect_to tags_path, notice: "Tag was successfully updated."
  #   else
  #     render inertia: "tags/Edit", props: {
  #       tag: @tag.as_json,
  #       errors: @tag.errors
  #     }, status: :unprocessable_entity
  #   end
  # end

  # def destroy
  #   @tag = Tag.find(params[:id])
  #   @tag.destroy

  #   redirect_to tags_path, notice: "Tag was successfully deleted."
  # end

  private

  def tag_params
    params.require(:tag).permit(:name, :catalog)
  end
end
