import * as Select from '@radix-ui/react-select'
import { ChevronDownIcon, ChevronUpIcon, XMarkIcon } from '@heroicons/react/24/solid'

export default function ComImageStatusSelect({
  value,  
  onChange,
  disabled = false,
  allowAll = true
}) {
  return (
    <Select.Root 
      value={value} 
      onValueChange={onChange}
      disabled={disabled}
    >
      <div className="relative">
        <Select.Trigger className="mt-1 inline-flex items-center justify-between w-full px-3 py-2 text-sm border border-gray-300 rounded-md shadow-sm bg-white focus:outline-none focus:ring-2 focus:ring-indigo-500 focus:border-indigo-500">
          <Select.Value placeholder="选择状态" />
          <Select.Icon>
            <ChevronDownIcon className="h-4 w-4 text-gray-500" />
          </Select.Icon>
        </Select.Trigger>
        
        {value && (
          <button
            type="button"
            onClick={() => onChange('')}
            className="absolute right-8 top-1/2 -translate-y-1/2 text-gray-400 hover:text-gray-600"
            aria-label="清空状态筛选"
          >
            <XMarkIcon className="h-4 w-4" />
          </button>
        )}
      </div>
      
      <Select.Portal>
        <Select.Content className="overflow-hidden bg-white rounded-md shadow-lg border border-gray-200 z-50">
          <Select.ScrollUpButton className="flex items-center justify-center h-6 bg-white text-gray-700 cursor-default">
            <ChevronUpIcon className="h-4 w-4" />
          </Select.ScrollUpButton>
          
          <Select.Viewport className="p-1">
            <Select.Group>
              {
                allowAll && 
                  <Select.Item value="all" className="relative flex items-center h-8 px-6 py-2 text-sm rounded hover:bg-indigo-100 hover:text-indigo-900 cursor-pointer outline-none data-[highlighted]:bg-indigo-100 data-[highlighted]:text-indigo-900">
                    <Select.ItemText>全部状态</Select.ItemText>
                  </Select.Item>
              }
              <Select.Item value="pending" className="relative flex items-center h-8 px-6 py-2 text-sm rounded hover:bg-indigo-100 hover:text-indigo-900 cursor-pointer outline-none data-[highlighted]:bg-indigo-100 data-[highlighted]:text-indigo-900">
                <Select.ItemText>待审核</Select.ItemText>
              </Select.Item>
              <Select.Item value="approved" className="relative flex items-center h-8 px-6 py-2 text-sm rounded hover:bg-indigo-100 hover:text-indigo-900 cursor-pointer outline-none data-[highlighted]:bg-indigo-100 data-[highlighted]:text-indigo-900">
                <Select.ItemText>已通过</Select.ItemText>
              </Select.Item>
              <Select.Item value="rejected" className="relative flex items-center h-8 px-6 py-2 text-sm rounded hover:bg-indigo-100 hover:text-indigo-900 cursor-pointer outline-none data-[highlighted]:bg-indigo-100 data-[highlighted]:text-indigo-900">
                <Select.ItemText>已拒绝</Select.ItemText>
              </Select.Item>
            </Select.Group>
          </Select.Viewport>
          
          <Select.ScrollDownButton className="flex items-center justify-center h-6 bg-white text-gray-700 cursor-default">
            <ChevronDownIcon className="h-4 w-4" />
          </Select.ScrollDownButton>
        </Select.Content>
      </Select.Portal>
    </Select.Root>
  )
}