import { Head, useForm, router } from '@inertiajs/react'
import Layout from '../../Layout'
import ImageUploadForm from '../../../components/ImageUploadForm'

export default function AdminImagesEdit({ image, tags, auth }) {
  // 初始化已有标签的ID数组
  const initialTagIds = image.tags
    ? image.tags.map(tag => tag.id)
    : []
    
  const { data, setData, processing, errors } = useForm({
    title: image.title || '',
    status: image.status,
    tag_ids: initialTagIds,
  })

  const handleSubmit = (e) => {
    e.preventDefault()
    router.patch(`/admin/images/${image.id}`, { image: data })
  }

  return (
    <Layout user={auth}>
      <Head title={`管理 - 编辑 ${image.title}`} />
      
      <div className="bg-white shadow overflow-hidden sm:rounded-lg">
        <div className="px-4 py-5 sm:px-6">
          <h1 className="text-2xl font-bold text-gray-900">编辑图片</h1>
          <p className="mt-1 max-w-2xl text-sm text-gray-500">
            更新图片信息
          </p>
        </div>
        <div className="border-t border-gray-200 px-4 py-5 sm:px-6">
          <ImageUploadForm
            data={data}
            setData={setData}
            processing={processing}
            errors={errors}
            onSubmit={handleSubmit}
            submitButtonText="保存"
            processingButtonText="保存中..."
            showTagsField={true}
            showStatusField={true}
            isEdit={true}
            image={image}
            tags={tags}
            cancelUrl={`/admin/images/${image.id}`}
          />
        </div>
      </div>
    </Layout>
  )
}
