import { Head, useForm, router } from '@inertiajs/react'
import Layout from '../Layout'
import ImageUploadForm from '../../components/ImageUploadForm'

export default function New({ auth, tags = [], errors = {} }) {
  const { data, setData, processing } = useForm({
    title: '',
    file: null,
    tag_ids: [],
  })

  const handleSubmit = (e) => {
    e.preventDefault()
    router.post('/images', { image: data })
  }

  return (
    <Layout user={auth}>
      <Head title="上传新图片" />
      <div className="bg-white shadow overflow-hidden sm:rounded-lg">
        <div className="px-4 py-5 sm:px-6">
          <h1 className="text-2xl font-bold text-gray-900">上传新图片</h1>
          <p className="mt-1 max-w-2xl text-sm text-gray-500">
            上传并等待审核
          </p>
        </div>
        <div className="border-t border-gray-200 px-4 py-5 sm:px-6">
          <ImageUploadForm
            data={data}
            setData={setData}
            processing={processing}
            errors={errors}
            onSubmit={handleSubmit}
            submitButtonText="上传图片"
            processingButtonText="上传中..."
            showTagsField={false}
            cancelUrl="/images"
          />
        </div>
      </div>
    </Layout>
  )
}
