import { useState } from 'react'
import { Head, useForm } from '@inertiajs/react'
import Layout from '../Layout'
import * as Form from '@radix-ui/react-form'

export default function TagsEdit({ tag, auth, errors = {} }) {
  const { data, setData, patch, processing } = useForm({
    name: tag.name,
    catalog: tag.catalog || '',
  })

  const handleSubmit = (e) => {
    e.preventDefault()
    patch(`/tags/${tag.id}`)
  }

  return (
    <Layout user={auth}>
      <Head title="Edit Tag" />
      <div className="max-w-2xl mx-auto py-6 sm:px-6 lg:px-8">
        <div className="bg-white shadow overflow-hidden sm:rounded-lg">
          <div className="px-4 py-5 sm:px-6">
            <h1 className="text-lg font-medium leading-6 text-gray-900">Edit Tag</h1>
            <p className="mt-1 max-w-2xl text-sm text-gray-500">
              Update tag information
            </p>
          </div>
          <div className="border-t border-gray-200 px-4 py-5 sm:p-6">
            <Form.Root className="space-y-6" onSubmit={handleSubmit}>
              <Form.Field name="name" className="space-y-2">
                <Form.Label className="block text-sm font-medium text-gray-700">
                  Tag Name
                </Form.Label>
                <Form.Control asChild>
                  <input
                    type="text"
                    name="name"
                    value={data.name}
                    onChange={(e) => setData('name', e.target.value)}
                    className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                    placeholder="Enter tag name"
                    required
                  />
                </Form.Control>
                {errors.name && (
                  <Form.Message className="text-sm text-red-600">
                    {errors.name}
                  </Form.Message>
                )}
              </Form.Field>

              <Form.Field name="catalog" className="space-y-2">
                <Form.Label className="block text-sm font-medium text-gray-700">
                  Catalog (Optional)
                </Form.Label>
                <Form.Control asChild>
                  <input
                    type="text"
                    name="catalog"
                    value={data.catalog}
                    onChange={(e) => setData('catalog', e.target.value)}
                    className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                    placeholder="Enter catalog name (e.g. 'Nature', 'Technology')"
                  />
                </Form.Control>
                <p className="text-xs text-gray-500">
                  Tags are grouped by catalog. Leave empty for uncategorized tags.
                </p>
                {errors.catalog && (
                  <Form.Message className="text-sm text-red-600">
                    {errors.catalog}
                  </Form.Message>
                )}
              </Form.Field>

              <div className="flex justify-end">
                <a
                  href="/tags"
                  className="bg-white py-2 px-4 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 mr-3"
                >
                  Cancel
                </a>
                <button
                  type="submit"
                  disabled={processing}
                  className="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                >
                  {processing ? 'Updating...' : 'Update Tag'}
                </button>
              </div>
            </Form.Root>
          </div>
        </div>
      </div>
    </Layout>
  )
}
